Error

Enum Error 

pub enum Error {
    ConnectToServer,
    WriteToStream,
    ReadStream,
    SwitchMode,
    RunCommand,
    QueryResponse(&'static str),
    WrongResponse,
    UnsupportedCommand((&'static str, Option<ChannelMode>)),
    SonicServer(String),
}
Wrap for sonic channel error kind. This type has std::error::Error implementation and you can use boxed trait for catch other errors like this. All error kinds that you can see in sonic-channel crate.

Variants



ConnectToServer

Cannot connect to the sonic search backend.



WriteToStream

Cannot write message to stream.



ReadStream

Cannot read message in stream.



SwitchMode

Cannot switch channel mode from uninitialized.



RunCommand

Cannot run command in current mode.



QueryResponse(&'static str)

Error in query response with additional message.



WrongResponse

Response from sonic server are wrong! Actually it may happen if you use unsupported sonic backend version. Please write issue to the github repo.



UnsupportedCommand((&'static str, Option<ChannelMode>))

You cannot run the command in current channel.



SonicServer(String)

This error appears if the error occurred on the server side